Re-exports
pub use anti_selection_area::AntiSelectionArea;pub use button::Button;pub use checkbox::Checkbox;pub use combobox::ComboBox;pub use combobox::ComboBoxCommitMode;pub use combobox::ComboBoxFilterMode;pub use combobox::ComboBoxItem;pub use context_menu::ContextMenu;pub use context_menu::ContextMenuAction;pub use context_menu::ContextMenuVisibilityChangedEventArgs;pub use context_menu::MenuItem;pub use control_template_set::clear_control_templates;pub use control_template_set::get_control_templates;pub use control_template_set::use_control_templates;pub use control_template_set::ControlTemplateSet;pub use control_tokens::ButtonColors;pub use control_tokens::DropdownColors;pub use control_tokens::DropdownSizing;pub use control_tokens::LabeledControlColors;pub use control_tokens::LabeledControlSizing;pub use control_tokens::ProgressBarColors;pub use control_tokens::ProgressBarSizing;pub use control_tokens::SliderColors;pub use control_tokens::SliderSizing;pub use control_tokens::TextInputColors;pub use dialog::Dialog;pub use dialog::DialogShownEventArgs;pub use dropdown::Dropdown;pub use dropdown::DropdownItem;pub use form::Form;pub use popup::Popup;pub use progress_bar::ProgressBar;pub use radio_button::RadioButton;pub use radio_group::RadioGroup;pub use selection_area::SelectionArea;pub use slider::Slider;pub use switch::Switch;pub use templating::create_default_checkbox_indicator_presenter;pub use templating::create_default_dropdown_chevron_presenter;pub use templating::create_default_dropdown_field_presenter;pub use templating::create_default_dropdown_option_row_presenter;pub use templating::create_default_radio_indicator_presenter;pub use templating::create_default_slider_presenter;pub use templating::create_default_switch_indicator_presenter;pub use templating::create_default_text_input_presenter;pub use templating::ButtonPresenter;pub use templating::ButtonTemplate;pub use templating::ButtonVisualState;pub use templating::CheckboxIndicatorPresenter;pub use templating::CheckboxIndicatorTemplate;pub use templating::CheckboxIndicatorVisualState;pub use templating::DefaultButtonTemplate;pub use templating::DefaultCheckboxIndicatorTemplate;pub use templating::DefaultDropdownChevronTemplate;pub use templating::DefaultDropdownFieldTemplate;pub use templating::DefaultDropdownOptionRowTemplate;pub use templating::DefaultRadioIndicatorTemplate;pub use templating::DefaultSliderTemplate;pub use templating::DefaultSwitchIndicatorTemplate;pub use templating::DefaultTextInputTemplate;pub use templating::DropdownChevronMetrics;pub use templating::DropdownChevronPresenter;pub use templating::DropdownChevronTemplate;pub use templating::DropdownChevronVisualState;pub use templating::DropdownFieldMetrics;pub use templating::DropdownFieldPresenter;pub use templating::DropdownFieldTemplate;pub use templating::DropdownFieldVisualState;pub use templating::DropdownOptionRowMetrics;pub use templating::DropdownOptionRowPresenter;pub use templating::DropdownOptionRowTemplate;pub use templating::DropdownOptionRowVisualState;pub use templating::PressableIndicatorMetrics;pub use templating::PressableIndicatorPresenter;pub use templating::PressableIndicatorVisualState;pub use templating::RadioIndicatorPresenter;pub use templating::RadioIndicatorTemplate;pub use templating::RadioIndicatorVisualState;pub use templating::SliderPresenter;pub use templating::SliderPresenterMetrics;pub use templating::SliderTemplate;pub use templating::SliderVisualState;pub use templating::SwitchIndicatorPresenter;pub use templating::SwitchIndicatorTemplate;pub use templating::SwitchIndicatorVisualState;pub use templating::TextInputPresenter;pub use templating::TextInputTemplate;pub use templating::TextInputVisualState;pub use templating::DEFAULT_BUTTON_TEMPLATE;pub use templating::DEFAULT_CHECKBOX_INDICATOR_TEMPLATE;pub use templating::DEFAULT_DROPDOWN_CHEVRON_TEMPLATE;pub use templating::DEFAULT_DROPDOWN_FIELD_TEMPLATE;pub use templating::DEFAULT_DROPDOWN_OPTION_ROW_TEMPLATE;pub use templating::DEFAULT_RADIO_INDICATOR_TEMPLATE;pub use templating::DEFAULT_SLIDER_TEMPLATE;pub use templating::DEFAULT_SWITCH_INDICATOR_TEMPLATE;pub use templating::DEFAULT_TEXT_INPUT_TEMPLATE;pub use text_area::TextArea;pub use text_input::TextInput;
Modules
- anti_
selection_ area - button
- checkbox
- combobox
- context_
menu - control_
template_ set - control_
tokens - dialog
- dropdown
- form
- nav_
link - popup
- progress_
bar - radio_
button - radio_
group - selection_
area - slider
- switch
- templating
- text_
area - text_
input
Structs
- Checkbox
Changed Event Args - Click
Event Args - Combo
BoxChanged Event Args - Context
Menu Appearance - Context
Menu Item Appearance - Dialog
Appearance - Dropdown
Changed Event Args - Overlay
Backdrop Appearance - Popup
Appearance - Radio
Button Changed Event Args - Radio
Group Changed Event Args - Slider
Changed Event Args - Surface
Appearance - Switch
Changed Event Args
Enums
Traits
- Clickable
- Semantic click activation for controls whose primary action can be invoked by pointer, keyboard, or another supported activation source.
- Labeled
Control Text Style - Text
Editor Surface - Shared editable-text behavior implemented by
TextInputandTextArea.