pub trait Clickable: Sized {
// Required method
fn on_click(&self, handler: impl Fn(ClickEventArgs) + 'static) -> &Self;
}Expand description
Semantic click activation for controls whose primary action can be invoked by pointer, keyboard, or another supported activation source.
Use Node::on_pointer_click when raw routed pointer data is required.
Required Methods
fn on_click(&self, handler: impl Fn(ClickEventArgs) + 'static) -> &Self
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".