pub struct DrawableInvalidator { /* private fields */ }Expand description
A weak invalidation handle that does not keep its CustomDrawable alive.
Implementations
Sourceimpl DrawableInvalidator
impl DrawableInvalidator
Sourcepub fn mark_dirty(&self)
pub fn mark_dirty(&self)
Schedules a redraw if the associated drawable is still mounted.